## 0.0.6 (2025-03-26)

### Feat

- Abort old request on new request
- Added finish listener support

## 0.0.5 (2024-10-25)

### Feat

- Allow to pass custom data to ajax redirect mixin

## 0.0.4 (2024-05-23)

### Feat

- Added configurable form row classes

## 0.0.3 (2023-11-27)

### Feat

- Pass pjaxOptions to request interceptor
- Pass event to pjax load if loaded automatically

## 0.0.2 (2023-07-19)

### Feat

- Added requestInterceptor

## 0.0.1 (2022-12-31)

### Feat

- Updated .gitignore
- Added middleware to modify XHR request

### Fix

- Fixed submit button detection if button is outside of form
- Process only text responses
- Revert back URL address on content type
- Select non field errors container using class instead of ID
- Don't send files in validation step
- Added empty values to formsets
- Cleared fallback error container

### Refactor

- Replaced setup.py with pyproject.toml
